"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class DashboardTokenResponseTypedDict(TypedDict):
    r"""Basic information about a dashboard."""

    embedded_id: str
    r"""Superset embedded ID of the dashboard"""
    guest_token: str
    r"""Superset guest token of the dashboard"""
    name: str
    r"""Name of the dashboard"""
    display_name: str
    r"""Display name of the dashboard"""
    superset_url: str
    r"""Superset URL of the dashboard"""
    rank: int
    r"""Dashboard importance, 0 is the highest"""
    label: str
    r"""Dashboard label.  Typically report or dashboard"""


class DashboardTokenResponse(BaseModel):
    r"""Basic information about a dashboard."""

    embedded_id: str
    r"""Superset embedded ID of the dashboard"""

    guest_token: str
    r"""Superset guest token of the dashboard"""

    name: str
    r"""Name of the dashboard"""

    display_name: str
    r"""Display name of the dashboard"""

    superset_url: str
    r"""Superset URL of the dashboard"""

    rank: int
    r"""Dashboard importance, 0 is the highest"""

    label: str
    r"""Dashboard label.  Typically report or dashboard"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class ToolParametersTypedDict(TypedDict):
    r"""Parameters for Insight Tool Definition"""


class ToolParameters(BaseModel):
    r"""Parameters for Insight Tool Definition"""


class ToolResultSetTypedDict(TypedDict):
    r"""Result key/types for Insight Tool Definition"""


class ToolResultSet(BaseModel):
    r"""Result key/types for Insight Tool Definition"""


class InsightToolDefinitionTypedDict(TypedDict):
    id: int
    r"""Unique ID for Insight Tool Definition"""
    name: str
    r"""Human readable name of Insight Tool Definition"""
    type: str
    r"""Type of Insight Tool Definition"""
    description: str
    r"""Text description of Insight Tool Definition"""
    tool_parameters: ToolParametersTypedDict
    r"""Parameters for Insight Tool Definition"""
    tool_result_set: ToolResultSetTypedDict
    r"""Result key/types for Insight Tool Definition"""


class InsightToolDefinition(BaseModel):
    id: int
    r"""Unique ID for Insight Tool Definition"""

    name: str
    r"""Human readable name of Insight Tool Definition"""

    type: str
    r"""Type of Insight Tool Definition"""

    description: str
    r"""Text description of Insight Tool Definition"""

    tool_parameters: ToolParameters
    r"""Parameters for Insight Tool Definition"""

    tool_result_set: ToolResultSet
    r"""Result key/types for Insight Tool Definition"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class DialogToolCallToolArgumentsTypedDict(TypedDict):
    pass


class DialogToolCallToolArguments(BaseModel):
    pass


class DialogToolCallTypedDict(TypedDict):
    tool_call_id: str
    tool_name: str
    tool_arguments: DialogToolCallToolArgumentsTypedDict
    timestamp: datetime


class DialogToolCall(BaseModel):
    tool_call_id: str

    tool_name: str

    tool_arguments: DialogToolCallToolArguments

    timestamp: datetime



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .insighttooloutput import InsightToolOutput, InsightToolOutputTypedDict
from datetime import datetime
from syllable_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class InsightWorkflowOutputConditionsTypedDict(TypedDict):
    r"""Conditions for Insight Workflow"""


class InsightWorkflowOutputConditions(BaseModel):
    r"""Conditions for Insight Workflow"""


class InsightWorkflowOutputTypedDict(TypedDict):
    name: str
    r"""Human readable name of Insight Workflow"""
    description: str
    r"""Text description of Insight Workflow"""
    insight_tool_ids: List[int]
    r"""List of Insight Tool IDs"""
    conditions: InsightWorkflowOutputConditionsTypedDict
    r"""Conditions for Insight Workflow"""
    status: str
    r"""Status of the Insight Workflow"""
    id: int
    r"""Unique ID for Insight Workflow"""
    insight_tools: List[InsightToolOutputTypedDict]
    r"""List of Insight Tools"""
    last_updated_by: str
    r"""User who last updated Insight Workflow"""
    created_at: NotRequired[datetime]
    r"""Timestamp of Insight Workflow creation"""
    updated_at: NotRequired[datetime]
    r"""Timestamp of Insight Workflow update"""


class InsightWorkflowOutput(BaseModel):
    name: str
    r"""Human readable name of Insight Workflow"""

    description: str
    r"""Text description of Insight Workflow"""

    insight_tool_ids: List[int]
    r"""List of Insight Tool IDs"""

    conditions: InsightWorkflowOutputConditions
    r"""Conditions for Insight Workflow"""

    status: str
    r"""Status of the Insight Workflow"""

    id: int
    r"""Unique ID for Insight Workflow"""

    insight_tools: List[InsightToolOutput]
    r"""List of Insight Tools"""

    last_updated_by: str
    r"""User who last updated Insight Workflow"""

    created_at: Optional[datetime] = None
    r"""Timestamp of Insight Workflow creation"""

    updated_at: Optional[datetime] = None
    r"""Timestamp of Insight Workflow update"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .sessionmessage import SessionMessage, SessionMessageTypedDict
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class SessionDataTypedDict(TypedDict):
    session_id: int
    source: str
    target: str
    is_test: bool
    messages: List[SessionMessageTypedDict]


class SessionData(BaseModel):
    session_id: int

    source: str

    target: str

    is_test: bool

    messages: List[SessionMessage]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dialogmessage import DialogMessage, DialogMessageTypedDict
from .dialogrole import DialogRole
from .dialogtoolcall import DialogToolCall, DialogToolCallTypedDict
from datetime import datetime
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class SessionMessageTypedDict(TypedDict):
    role: DialogRole
    dialog: DialogMessageTypedDict
    tool_calls: List[DialogToolCallTypedDict]
    timestamp: datetime


class SessionMessage(BaseModel):
    role: DialogRole

    dialog: DialogMessage

    tool_calls: List[DialogToolCall]

    timestamp: datetime



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .sdkconfiguration import SDKConfiguration
from syllable_sdk.insights_tools import InsightsTools
from syllable_sdk.workflows import Workflows


class Insights(BaseSDK):
    workflows: Workflows
    r"""Operations related to insights workflows. An workflow is series of tool           invocations that processes conversation data to extract information and generate reports."""
    tools: InsightsTools
    r"""Operations related to insights tools. An insight is a tool that processes           conversation data to extract information and generate reports."""

    def __init__(self, sdk_config: SDKConfiguration) -> None:
        BaseSDK.__init__(self, sdk_config)
        self.sdk_configuration = sdk_config
        self._init_sdks()

    def _init_sdks(self):
        self.workflows = Workflows(self.sdk_configuration)
        self.tools = InsightsTools(self.sdk_configuration)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class InsightToolInputToolArgumentsTypedDict(TypedDict):
    r"""Arguments for Insight Tool"""


class InsightToolInputToolArguments(BaseModel):
    r"""Arguments for Insight Tool"""


class InsightToolInputTypedDict(TypedDict):
    name: str
    r"""Human readable name of Insight Tool"""
    description: str
    r"""Text description of Insight Tool"""
    version: int
    r"""Version number of Insight Tool"""
    tool_arguments: InsightToolInputToolArgumentsTypedDict
    r"""Arguments for Insight Tool"""
    insight_tool_definition_id: int
    r"""Unique ID for Insight Tool Definition"""


class InsightToolInput(BaseModel):
    name: str
    r"""Human readable name of Insight Tool"""

    description: str
    r"""Text description of Insight Tool"""

    version: int
    r"""Version number of Insight Tool"""

    tool_arguments: InsightToolInputToolArguments
    r"""Arguments for Insight Tool"""

    insight_tool_definition_id: int
    r"""Unique ID for Insight Tool Definition"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing_extensions import TypedDict


class ToolResultTypedDict(TypedDict):
    pass


class ToolResult(BaseModel):
    pass


class ToolResultDataTypedDict(TypedDict):
    tool_name: str
    tool_result: ToolResultTypedDict


class ToolResultData(BaseModel):
    tool_name: str

    tool_result: ToolResult



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from syllable_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class InsightWorkflowInputConditionsTypedDict(TypedDict):
    r"""Conditions for Insight Workflow"""


class InsightWorkflowInputConditions(BaseModel):
    r"""Conditions for Insight Workflow"""


class InsightWorkflowInputTypedDict(TypedDict):
    name: str
    r"""Human readable name of Insight Workflow"""
    description: str
    r"""Text description of Insight Workflow"""
    insight_tool_ids: List[int]
    r"""List of Insight Tool IDs"""
    conditions: InsightWorkflowInputConditionsTypedDict
    r"""Conditions for Insight Workflow"""
    status: str
    r"""Status of the Insight Workflow"""


class InsightWorkflowInput(BaseModel):
    name: str
    r"""Human readable name of Insight Workflow"""

    description: str
    r"""Text description of Insight Workflow"""

    insight_tool_ids: List[int]
    r"""List of Insight Tool IDs"""

    conditions: InsightWorkflowInputConditions
    r"""Conditions for Insight Workflow"""

    status: str
    r"""Status of the Insight Workflow"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class LanguageGroupProperties(str, Enum):
    NAME = "name"
    DESCRIPTION = "description"
    SKIP_CURRENT_LANGUAGE_IN_MESSAGE = "skip_current_language_in_message"
    UPDATED_AT = "updated_at"
    LAST_UPDATED_BY = "last_updated_by"
